Class: DocuSign_Click::BaseAgreeButtonStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/models/base_agree_button_styles.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseAgreeButtonStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 125

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'backgroundColor')
    self.background_color = attributes[:'backgroundColor']
  end

  if attributes.has_key?(:'border')
    self.border = attributes[:'border']
  end

  if attributes.has_key?(:'borderColor')
    self.border_color = attributes[:'borderColor']
  end

  if attributes.has_key?(:'borderRadius')
    self.border_radius = attributes[:'borderRadius']
  end

  if attributes.has_key?(:'borderStyle')
    self.border_style = attributes[:'borderStyle']
  end

  if attributes.has_key?(:'borderWidth')
    self.border_width = attributes[:'borderWidth']
  end

  if attributes.has_key?(:'boxShadow')
    self.box_shadow = attributes[:'boxShadow']
  end

  if attributes.has_key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.has_key?(:'fontFamily')
    self.font_family = attributes[:'fontFamily']
  end

  if attributes.has_key?(:'fontSize')
    self.font_size = attributes[:'fontSize']
  end

  if attributes.has_key?(:'fontStyle')
    self.font_style = attributes[:'fontStyle']
  end

  if attributes.has_key?(:'fontWeight')
    self.font_weight = attributes[:'fontWeight']
  end

  if attributes.has_key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.has_key?(:'margin')
    self.margin = attributes[:'margin']
  end

  if attributes.has_key?(:'opacity')
    self.opacity = attributes[:'opacity']
  end

  if attributes.has_key?(:'outline')
    self.outline = attributes[:'outline']
  end

  if attributes.has_key?(:'outlineOffset')
    self.outline_offset = attributes[:'outlineOffset']
  end

  if attributes.has_key?(:'padding')
    self.padding = attributes[:'padding']
  end

  if attributes.has_key?(:'width')
    self.width = attributes[:'width']
  end
end

Instance Attribute Details

#background_colorObject

Control the background color of the element.



17
18
19
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 17

def background_color
  @background_color
end

#borderObject

Control the border of the element.



20
21
22
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 20

def border
  @border
end

#border_colorObject

Control the border color of the element.



23
24
25
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 23

def border_color
  @border_color
end

#border_radiusObject

Control the border radius of the element.



26
27
28
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 26

def border_radius
  @border_radius
end

#border_styleObject

Control the border style of the element.



29
30
31
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 29

def border_style
  @border_style
end

#border_widthObject

Control the border width of the element.



32
33
34
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 32

def border_width
  @border_width
end

#box_shadowObject

Control the display of the box shadow of the agree button.



35
36
37
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 35

def box_shadow
  @box_shadow
end

#colorObject

Control the fore-ground color of the element.



38
39
40
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 38

def color
  @color
end

#font_familyObject

Control the font family of the text.



41
42
43
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 41

def font_family
  @font_family
end

#font_sizeObject

Control the font size of the text.



44
45
46
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 44

def font_size
  @font_size
end

#font_styleObject

Control the font style of the text.



47
48
49
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 47

def font_style
  @font_style
end

#font_weightObject

Control the font weight of the text.



50
51
52
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 50

def font_weight
  @font_weight
end

#heightObject

Control the height of the agree button.



53
54
55
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 53

def height
  @height
end

#marginObject

Control the margin of the element.



56
57
58
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 56

def margin
  @margin
end

#opacityObject

Control the opacity of the element



59
60
61
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 59

def opacity
  @opacity
end

#outlineObject

Control the outline of the element



62
63
64
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 62

def outline
  @outline
end

#outline_offsetObject

Conrol the outline offset of the element



65
66
67
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 65

def outline_offset
  @outline_offset
end

#paddingObject

Control the padding of the element.



68
69
70
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 68

def padding
  @padding
end

#widthObject

Control the width of the agree button.



71
72
73
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 71

def width
  @width
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 74

def self.attribute_map
  {
    :'background_color' => :'backgroundColor',
    :'border' => :'border',
    :'border_color' => :'borderColor',
    :'border_radius' => :'borderRadius',
    :'border_style' => :'borderStyle',
    :'border_width' => :'borderWidth',
    :'box_shadow' => :'boxShadow',
    :'color' => :'color',
    :'font_family' => :'fontFamily',
    :'font_size' => :'fontSize',
    :'font_style' => :'fontStyle',
    :'font_weight' => :'fontWeight',
    :'height' => :'height',
    :'margin' => :'margin',
    :'opacity' => :'opacity',
    :'outline' => :'outline',
    :'outline_offset' => :'outlineOffset',
    :'padding' => :'padding',
    :'width' => :'width'
  }
end

.swagger_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 99

def self.swagger_types
  {
    :'background_color' => :'String',
    :'border' => :'String',
    :'border_color' => :'String',
    :'border_radius' => :'String',
    :'border_style' => :'String',
    :'border_width' => :'String',
    :'box_shadow' => :'String',
    :'color' => :'String',
    :'font_family' => :'String',
    :'font_size' => :'String',
    :'font_style' => :'String',
    :'font_weight' => :'Object',
    :'height' => :'String',
    :'margin' => :'String',
    :'opacity' => :'String',
    :'outline' => :'String',
    :'outline_offset' => :'String',
    :'padding' => :'String',
    :'width' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 223

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      background_color == o.background_color &&
      border == o.border &&
      border_color == o.border_color &&
      border_radius == o.border_radius &&
      border_style == o.border_style &&
      border_width == o.border_width &&
      box_shadow == o.box_shadow &&
      color == o.color &&
      font_family == o.font_family &&
      font_size == o.font_size &&
      font_style == o.font_style &&
      font_weight == o.font_weight &&
      height == o.height &&
      margin == o.margin &&
      opacity == o.opacity &&
      outline == o.outline &&
      outline_offset == o.outline_offset &&
      padding == o.padding &&
      width == o.width
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 283

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_Click.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 349

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 262

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


249
250
251
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 249

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



255
256
257
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 255

def hash
  [background_color, border, border_color, border_radius, border_style, border_width, box_shadow, color, font_family, font_size, font_style, font_weight, height, margin, opacity, outline, outline_offset, padding, width].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



210
211
212
213
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 210

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 329

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



335
336
337
338
339
340
341
342
343
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 335

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



323
324
325
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 323

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



217
218
219
# File 'lib/docusign_click/models/base_agree_button_styles.rb', line 217

def valid?
  true
end