Class: DocuSign_Click::ClickwrapRequest
- Inherits:
-
Object
- Object
- DocuSign_Click::ClickwrapRequest
- Defined in:
- lib/docusign_click/models/clickwrap_request.rb
Overview
Request body for working with clickwrap.
Instance Attribute Summary collapse
-
#clickwrap_name ⇒ Object
The name of the clickwrap.
-
#data_fields ⇒ Object
An array of data fields available to be inserted into the documents.
-
#display_settings ⇒ Object
Display settings for the clickwrap.
-
#documents ⇒ Object
An array of documents.
-
#fields_to_null ⇒ Object
Specifies whether
scheduledReacceptanceandscheduledDateshould be cleared. -
#is_major_version ⇒ Object
Not used.
-
#is_shared ⇒ Object
When **true,** indicates that the clickwrap is shared with one or more users in the account.
-
#name ⇒ Object
Not used.
-
#require_reacceptance ⇒ Object
When **true,** requires signers who have previously agreed to this clickwrap to sign again.
-
#scheduled_date ⇒ Object
The time and date when this clickwrap is activated.
-
#scheduled_reacceptance ⇒ Object
Specifies the interval between reacceptances in days, weeks, months, or years.
-
#status ⇒ Object
Clickwrap status.
-
#transfer_from_user_id ⇒ Object
Not used.
-
#transfer_to_user_id ⇒ Object
Not used.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClickwrapRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ClickwrapRequest
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'clickwrapName') self.clickwrap_name = attributes[:'clickwrapName'] end if attributes.has_key?(:'dataFields') if (value = attributes[:'dataFields']).is_a?(Array) self.data_fields = value end end if attributes.has_key?(:'displaySettings') self.display_settings = attributes[:'displaySettings'] end if attributes.has_key?(:'documents') if (value = attributes[:'documents']).is_a?(Array) self.documents = value end end if attributes.has_key?(:'fieldsToNull') self.fields_to_null = attributes[:'fieldsToNull'] end if attributes.has_key?(:'isMajorVersion') self.is_major_version = attributes[:'isMajorVersion'] end if attributes.has_key?(:'isShared') self.is_shared = attributes[:'isShared'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'requireReacceptance') self.require_reacceptance = attributes[:'requireReacceptance'] end if attributes.has_key?(:'scheduledDate') self.scheduled_date = attributes[:'scheduledDate'] end if attributes.has_key?(:'scheduledReacceptance') self.scheduled_reacceptance = attributes[:'scheduledReacceptance'] end if attributes.has_key?(:'status') self.status = attributes[:'status'] end if attributes.has_key?(:'transferFromUserId') self.transfer_from_user_id = attributes[:'transferFromUserId'] end if attributes.has_key?(:'transferToUserId') self.transfer_to_user_id = attributes[:'transferToUserId'] end end |
Instance Attribute Details
#clickwrap_name ⇒ Object
The name of the clickwrap. This field is required.
18 19 20 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 18 def clickwrap_name @clickwrap_name end |
#data_fields ⇒ Object
An array of data fields available to be inserted into the documents.
21 22 23 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 21 def data_fields @data_fields end |
#display_settings ⇒ Object
Display settings for the clickwrap. This object is required.
24 25 26 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 24 def display_settings @display_settings end |
#documents ⇒ Object
An array of documents. This object is required.
27 28 29 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 27 def documents @documents end |
#fields_to_null ⇒ Object
Specifies whether scheduledReacceptance and scheduledDate should be cleared. May be one of: - ‘"scheduledReacceptance"` - `"scheduledDate"` - `"scheduledReacceptance,scheduledDate"`
30 31 32 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 30 def fields_to_null @fields_to_null end |
#is_major_version ⇒ Object
Not used.
33 34 35 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 33 def is_major_version @is_major_version end |
#is_shared ⇒ Object
When **true,** indicates that the clickwrap is shared with one or more users in the account.
36 37 38 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 36 def is_shared @is_shared end |
#name ⇒ Object
Not used.
39 40 41 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 39 def name @name end |
#require_reacceptance ⇒ Object
When **true,** requires signers who have previously agreed to this clickwrap to sign again. The version number is incremented.
42 43 44 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 42 def require_reacceptance @require_reacceptance end |
#scheduled_date ⇒ Object
The time and date when this clickwrap is activated.
45 46 47 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 45 def scheduled_date @scheduled_date end |
#scheduled_reacceptance ⇒ Object
Specifies the interval between reacceptances in days, weeks, months, or years.
48 49 50 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 48 def scheduled_reacceptance @scheduled_reacceptance end |
#status ⇒ Object
Clickwrap status. This property is read-only. Possible values: - active - inactive - deleted
51 52 53 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 51 def status @status end |
#transfer_from_user_id ⇒ Object
Not used. To update the user ID of a clickwrap, use the [updateClickwrap](/docs/click-api/reference/accounts/clickwraps/updateclickwrap/) endpoint.
54 55 56 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 54 def transfer_from_user_id @transfer_from_user_id end |
#transfer_to_user_id ⇒ Object
Not used. To update the user ID of a clickwrap, use the [updateClickwrap](/docs/click-api/reference/accounts/clickwraps/updateclickwrap/) endpoint.
57 58 59 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 57 def transfer_to_user_id @transfer_to_user_id end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 60 def self.attribute_map { :'clickwrap_name' => :'clickwrapName', :'data_fields' => :'dataFields', :'display_settings' => :'displaySettings', :'documents' => :'documents', :'fields_to_null' => :'fieldsToNull', :'is_major_version' => :'isMajorVersion', :'is_shared' => :'isShared', :'name' => :'name', :'require_reacceptance' => :'requireReacceptance', :'scheduled_date' => :'scheduledDate', :'scheduled_reacceptance' => :'scheduledReacceptance', :'status' => :'status', :'transfer_from_user_id' => :'transferFromUserId', :'transfer_to_user_id' => :'transferToUserId' } end |
.swagger_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 80 def self.swagger_types { :'clickwrap_name' => :'String', :'data_fields' => :'Array<DataField>', :'display_settings' => :'DisplaySettings', :'documents' => :'Array<Document>', :'fields_to_null' => :'String', :'is_major_version' => :'BOOLEAN', :'is_shared' => :'BOOLEAN', :'name' => :'String', :'require_reacceptance' => :'BOOLEAN', :'scheduled_date' => :'Object', :'scheduled_reacceptance' => :'ClickwrapScheduledReacceptance', :'status' => :'String', :'transfer_from_user_id' => :'String', :'transfer_to_user_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && clickwrap_name == o.clickwrap_name && data_fields == o.data_fields && display_settings == o.display_settings && documents == o.documents && fields_to_null == o.fields_to_null && is_major_version == o.is_major_version && is_shared == o.is_shared && name == o.name && require_reacceptance == o.require_reacceptance && scheduled_date == o.scheduled_date && scheduled_reacceptance == o.scheduled_reacceptance && status == o.status && transfer_from_user_id == o.transfer_from_user_id && transfer_to_user_id == o.transfer_to_user_id end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 238 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = DocuSign_Click.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
304 305 306 307 308 309 310 311 312 313 314 315 316 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 304 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 217 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
204 205 206 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 204 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 210 def hash [clickwrap_name, data_fields, display_settings, documents, fields_to_null, is_major_version, is_shared, name, require_reacceptance, scheduled_date, scheduled_reacceptance, status, transfer_from_user_id, transfer_to_user_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 170 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
284 285 286 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 284 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
278 279 280 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 278 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 |
# File 'lib/docusign_click/models/clickwrap_request.rb', line 177 def valid? true end |