Class: DocuSign_Click::ClickwrapVersionResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/models/clickwrap_version_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClickwrapVersionResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 115

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'accountId')
    self. = attributes[:'accountId']
  end

  if attributes.has_key?(:'clickwrapId')
    self.clickwrap_id = attributes[:'clickwrapId']
  end

  if attributes.has_key?(:'clickwrapName')
    self.clickwrap_name = attributes[:'clickwrapName']
  end

  if attributes.has_key?(:'clickwrapVersionId')
    self.clickwrap_version_id = attributes[:'clickwrapVersionId']
  end

  if attributes.has_key?(:'createdTime')
    self.created_time = attributes[:'createdTime']
  end

  if attributes.has_key?(:'dataFields')
    if (value = attributes[:'dataFields']).is_a?(Array)
      self.data_fields = value
    end
  end

  if attributes.has_key?(:'displaySettings')
    self.display_settings = attributes[:'displaySettings']
  end

  if attributes.has_key?(:'documents')
    if (value = attributes[:'documents']).is_a?(Array)
      self.documents = value
    end
  end

  if attributes.has_key?(:'lastModified')
    self.last_modified = attributes[:'lastModified']
  end

  if attributes.has_key?(:'lastModifiedBy')
    self.last_modified_by = attributes[:'lastModifiedBy']
  end

  if attributes.has_key?(:'ownerUserId')
    self.owner_user_id = attributes[:'ownerUserId']
  end

  if attributes.has_key?(:'requireReacceptance')
    self.require_reacceptance = attributes[:'requireReacceptance']
  end

  if attributes.has_key?(:'scheduledDate')
    self.scheduled_date = attributes[:'scheduledDate']
  end

  if attributes.has_key?(:'scheduledReacceptance')
    self.scheduled_reacceptance = attributes[:'scheduledReacceptance']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'versionId')
    self.version_id = attributes[:'versionId']
  end

  if attributes.has_key?(:'versionNumber')
    self.version_number = attributes[:'versionNumber']
  end
end

Instance Attribute Details

#account_idObject

The external account number (int) or account ID GUID.



17
18
19
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 17

def 
  @account_id
end

#clickwrap_idObject

The ID of the clickwrap.



20
21
22
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 20

def clickwrap_id
  @clickwrap_id
end

#clickwrap_nameObject

The name of the clickwrap.



23
24
25
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 23

def clickwrap_name
  @clickwrap_name
end

#clickwrap_version_idObject

The unique version ID, a GUID, of this clickwrap version.



26
27
28
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 26

def clickwrap_version_id
  @clickwrap_version_id
end

#created_timeObject

The time that the clickwrap was created.



29
30
31
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 29

def created_time
  @created_time
end

#data_fieldsObject

The list of all the data fields available for the clickwrap (custom fields and standard fields).



32
33
34
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 32

def data_fields
  @data_fields
end

#display_settingsObject

Display settings for a clickwrap.



35
36
37
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 35

def display_settings
  @display_settings
end

#documentsObject

An array of documents.



38
39
40
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 38

def documents
  @documents
end

#last_modifiedObject

The time that the clickwrap was last modified.



41
42
43
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 41

def last_modified
  @last_modified
end

#last_modified_byObject

The user ID of the last user who modified this clickwrap.



44
45
46
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 44

def last_modified_by
  @last_modified_by
end

#owner_user_idObject

The user ID of the owner of this clickwrap.



47
48
49
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 47

def owner_user_id
  @owner_user_id
end

#require_reacceptanceObject

When **true,** requires signers who have previously agreed to this clickwrap to sign again. The version number is incremented.



50
51
52
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 50

def require_reacceptance
  @require_reacceptance
end

#scheduled_dateObject

The time and date when this clickwrap is activated.



53
54
55
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 53

def scheduled_date
  @scheduled_date
end

#scheduled_reacceptanceObject

Specifies the interval between reacceptances in days, weeks, months, or years.



56
57
58
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 56

def scheduled_reacceptance
  @scheduled_reacceptance
end

#statusObject

Clickwrap status. Possible values: - active - inactive - deleted



59
60
61
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 59

def status
  @status
end

#version_idObject

The ID of the version.



62
63
64
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 62

def version_id
  @version_id
end

#version_numberObject

Version of the clickwrap.



65
66
67
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 65

def version_number
  @version_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 68

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'clickwrap_id' => :'clickwrapId',
    :'clickwrap_name' => :'clickwrapName',
    :'clickwrap_version_id' => :'clickwrapVersionId',
    :'created_time' => :'createdTime',
    :'data_fields' => :'dataFields',
    :'display_settings' => :'displaySettings',
    :'documents' => :'documents',
    :'last_modified' => :'lastModified',
    :'last_modified_by' => :'lastModifiedBy',
    :'owner_user_id' => :'ownerUserId',
    :'require_reacceptance' => :'requireReacceptance',
    :'scheduled_date' => :'scheduledDate',
    :'scheduled_reacceptance' => :'scheduledReacceptance',
    :'status' => :'status',
    :'version_id' => :'versionId',
    :'version_number' => :'versionNumber'
  }
end

.swagger_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 91

def self.swagger_types
  {
    :'account_id' => :'String',
    :'clickwrap_id' => :'String',
    :'clickwrap_name' => :'String',
    :'clickwrap_version_id' => :'String',
    :'created_time' => :'Object',
    :'data_fields' => :'Array<DataField>',
    :'display_settings' => :'DisplaySettings',
    :'documents' => :'Array<Document>',
    :'last_modified' => :'Object',
    :'last_modified_by' => :'String',
    :'owner_user_id' => :'String',
    :'require_reacceptance' => :'BOOLEAN',
    :'scheduled_date' => :'Object',
    :'scheduled_reacceptance' => :'ClickwrapScheduledReacceptance',
    :'status' => :'String',
    :'version_id' => :'String',
    :'version_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      clickwrap_id == o.clickwrap_id &&
      clickwrap_name == o.clickwrap_name &&
      clickwrap_version_id == o.clickwrap_version_id &&
      created_time == o.created_time &&
      data_fields == o.data_fields &&
      display_settings == o.display_settings &&
      documents == o.documents &&
      last_modified == o.last_modified &&
      last_modified_by == o.last_modified_by &&
      owner_user_id == o.owner_user_id &&
      require_reacceptance == o.require_reacceptance &&
      scheduled_date == o.scheduled_date &&
      scheduled_reacceptance == o.scheduled_reacceptance &&
      status == o.status &&
      version_id == o.version_id &&
      version_number == o.version_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 267

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_Click.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 333

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 246

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


233
234
235
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 233

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



239
240
241
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 239

def hash
  [, clickwrap_id, clickwrap_name, clickwrap_version_id, created_time, data_fields, display_settings, documents, last_modified, last_modified_by, owner_user_id, require_reacceptance, scheduled_date, scheduled_reacceptance, status, version_id, version_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 196

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



313
314
315
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 313

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



319
320
321
322
323
324
325
326
327
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 319

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



307
308
309
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 307

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
# File 'lib/docusign_click/models/clickwrap_version_response.rb', line 203

def valid?
  true
end