Class: DocuSign_Click::DisplaySettings

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/models/display_settings.rb

Overview

Information about how an agreement is displayed.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DisplaySettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/docusign_click/models/display_settings.rb', line 121

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'actionButtonAlignment')
    self.action_button_alignment = attributes[:'actionButtonAlignment']
  end

  if attributes.has_key?(:'allowClientOnly')
    self.allow_client_only = attributes[:'allowClientOnly']
  end

  if attributes.has_key?(:'allowedHosts')
    if (value = attributes[:'allowedHosts']).is_a?(Array)
      self.allowed_hosts = value
    end
  end

  if attributes.has_key?(:'brandId')
    self.brand_id = attributes[:'brandId']
  end

  if attributes.has_key?(:'consentButtonText')
    self.consent_button_text = attributes[:'consentButtonText']
  end

  if attributes.has_key?(:'consentText')
    self.consent_text = attributes[:'consentText']
  end

  if attributes.has_key?(:'declineButtonText')
    self.decline_button_text = attributes[:'declineButtonText']
  end

  if attributes.has_key?(:'displayName')
    self.display_name = attributes[:'displayName']
  end

  if attributes.has_key?(:'documentDisplay')
    self.document_display = attributes[:'documentDisplay']
  end

  if attributes.has_key?(:'downloadable')
    self.downloadable = attributes[:'downloadable']
  end

  if attributes.has_key?(:'format')
    self.format = attributes[:'format']
  end

  if attributes.has_key?(:'hasDeclineButton')
    self.has_decline_button = attributes[:'hasDeclineButton']
  end

  if attributes.has_key?(:'mustRead')
    self.must_read = attributes[:'mustRead']
  end

  if attributes.has_key?(:'mustView')
    self.must_view = attributes[:'mustView']
  end

  if attributes.has_key?(:'recordDeclineResponses')
    self.record_decline_responses = attributes[:'recordDeclineResponses']
  end

  if attributes.has_key?(:'requireAccept')
    self.require_accept = attributes[:'requireAccept']
  end

  if attributes.has_key?(:'sendToEmail')
    self.send_to_email = attributes[:'sendToEmail']
  end

  if attributes.has_key?(:'statementAlignment')
    self.statement_alignment = attributes[:'statementAlignment']
  end
end

Instance Attribute Details

#action_button_alignmentObject

Position of the Accept button in the agreement. One of - right - left



18
19
20
# File 'lib/docusign_click/models/display_settings.rb', line 18

def action_button_alignment
  @action_button_alignment
end

#allow_client_onlyObject

When **true,** this agreement can be be used in client-only integrations.



21
22
23
# File 'lib/docusign_click/models/display_settings.rb', line 21

def allow_client_only
  @allow_client_only
end

#allowed_hostsObject

Hosts that can host the clickwrap. It is an error if the clickwrap didn’t come from one of these hosts.



24
25
26
# File 'lib/docusign_click/models/display_settings.rb', line 24

def allowed_hosts
  @allowed_hosts
end

#brand_idObject

The signing brand ID.



27
28
29
# File 'lib/docusign_click/models/display_settings.rb', line 27

def brand_id
  @brand_id
end

Text on the agree button.



30
31
32
# File 'lib/docusign_click/models/display_settings.rb', line 30

def consent_button_text
  @consent_button_text
end

The statement prefixing the Electronic Record and Signature Disclosure agreement.



33
34
35
# File 'lib/docusign_click/models/display_settings.rb', line 33

def consent_text
  @consent_text
end

#decline_button_textObject

The text on the decline button.



36
37
38
# File 'lib/docusign_click/models/display_settings.rb', line 36

def decline_button_text
  @decline_button_text
end

#display_nameObject

The display name of the user agreement.



39
40
41
# File 'lib/docusign_click/models/display_settings.rb', line 39

def display_name
  @display_name
end

#document_displayObject

Display type: link, document or pdf



42
43
44
# File 'lib/docusign_click/models/display_settings.rb', line 42

def document_display
  @document_display
end

#downloadableObject

True if the agreement is downloadable.



45
46
47
# File 'lib/docusign_click/models/display_settings.rb', line 45

def downloadable
  @downloadable
end

#formatObject

Display format: inline or modal.



48
49
50
# File 'lib/docusign_click/models/display_settings.rb', line 48

def format
  @format
end

#has_decline_buttonObject

True if the agreement has a decline button.



51
52
53
# File 'lib/docusign_click/models/display_settings.rb', line 51

def has_decline_button
  @has_decline_button
end

#must_readObject

True if the user needs to scroll to the end of the document.



54
55
56
# File 'lib/docusign_click/models/display_settings.rb', line 54

def must_read
  @must_read
end

#must_viewObject

True if the user must view the document.



57
58
59
# File 'lib/docusign_click/models/display_settings.rb', line 57

def must_view
  @must_view
end

#record_decline_responsesObject

When **true,** this agreement records decline actions.



60
61
62
# File 'lib/docusign_click/models/display_settings.rb', line 60

def record_decline_responses
  @record_decline_responses
end

#require_acceptObject

True if a checkbox is required to accept.



63
64
65
# File 'lib/docusign_click/models/display_settings.rb', line 63

def require_accept
  @require_accept
end

#send_to_emailObject

True if send to email is applicable.



66
67
68
# File 'lib/docusign_click/models/display_settings.rb', line 66

def send_to_email
  @send_to_email
end

#statement_alignmentObject

Position of the agreement statement. One of - top - bottom



69
70
71
# File 'lib/docusign_click/models/display_settings.rb', line 69

def statement_alignment
  @statement_alignment
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/docusign_click/models/display_settings.rb', line 72

def self.attribute_map
  {
    :'action_button_alignment' => :'actionButtonAlignment',
    :'allow_client_only' => :'allowClientOnly',
    :'allowed_hosts' => :'allowedHosts',
    :'brand_id' => :'brandId',
    :'consent_button_text' => :'consentButtonText',
    :'consent_text' => :'consentText',
    :'decline_button_text' => :'declineButtonText',
    :'display_name' => :'displayName',
    :'document_display' => :'documentDisplay',
    :'downloadable' => :'downloadable',
    :'format' => :'format',
    :'has_decline_button' => :'hasDeclineButton',
    :'must_read' => :'mustRead',
    :'must_view' => :'mustView',
    :'record_decline_responses' => :'recordDeclineResponses',
    :'require_accept' => :'requireAccept',
    :'send_to_email' => :'sendToEmail',
    :'statement_alignment' => :'statementAlignment'
  }
end

.swagger_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/docusign_click/models/display_settings.rb', line 96

def self.swagger_types
  {
    :'action_button_alignment' => :'String',
    :'allow_client_only' => :'BOOLEAN',
    :'allowed_hosts' => :'Array<String>',
    :'brand_id' => :'String',
    :'consent_button_text' => :'String',
    :'consent_text' => :'String',
    :'decline_button_text' => :'String',
    :'display_name' => :'String',
    :'document_display' => :'String',
    :'downloadable' => :'BOOLEAN',
    :'format' => :'String',
    :'has_decline_button' => :'BOOLEAN',
    :'must_read' => :'BOOLEAN',
    :'must_view' => :'BOOLEAN',
    :'record_decline_responses' => :'BOOLEAN',
    :'require_accept' => :'BOOLEAN',
    :'send_to_email' => :'BOOLEAN',
    :'statement_alignment' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/docusign_click/models/display_settings.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      action_button_alignment == o.action_button_alignment &&
      allow_client_only == o.allow_client_only &&
      allowed_hosts == o.allowed_hosts &&
      brand_id == o.brand_id &&
      consent_button_text == o.consent_button_text &&
      consent_text == o.consent_text &&
      decline_button_text == o.decline_button_text &&
      display_name == o.display_name &&
      document_display == o.document_display &&
      downloadable == o.downloadable &&
      format == o.format &&
      has_decline_button == o.has_decline_button &&
      must_read == o.must_read &&
      must_view == o.must_view &&
      record_decline_responses == o.record_decline_responses &&
      require_accept == o.require_accept &&
      send_to_email == o.send_to_email &&
      statement_alignment == o.statement_alignment
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/docusign_click/models/display_settings.rb', line 276

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_Click.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/docusign_click/models/display_settings.rb', line 342

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/docusign_click/models/display_settings.rb', line 255

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


242
243
244
# File 'lib/docusign_click/models/display_settings.rb', line 242

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



248
249
250
# File 'lib/docusign_click/models/display_settings.rb', line 248

def hash
  [action_button_alignment, allow_client_only, allowed_hosts, brand_id, consent_button_text, consent_text, decline_button_text, display_name, document_display, downloadable, format, has_decline_button, must_read, must_view, record_decline_responses, require_accept, send_to_email, statement_alignment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
# File 'lib/docusign_click/models/display_settings.rb', line 204

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



322
323
324
# File 'lib/docusign_click/models/display_settings.rb', line 322

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



328
329
330
331
332
333
334
335
336
# File 'lib/docusign_click/models/display_settings.rb', line 328

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



316
317
318
# File 'lib/docusign_click/models/display_settings.rb', line 316

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



211
212
213
# File 'lib/docusign_click/models/display_settings.rb', line 211

def valid?
  true
end