Class: DocuSign_Click::GetAgreementPdfOptions
- Inherits:
-
Object
- Object
- DocuSign_Click::GetAgreementPdfOptions
- Defined in:
- lib/docusign_click/api/accounts_api.rb
Instance Attribute Summary collapse
-
#include_coc ⇒ Object
When **true,** the Certificate of Completion will be appended to the PDF.
Class Method Summary collapse
Instance Attribute Details
#include_coc ⇒ Object
When **true,** the Certificate of Completion will be appended to the PDF. The default value is false.
45 46 47 |
# File 'lib/docusign_click/api/accounts_api.rb', line 45 def include_coc @include_coc end |
Class Method Details
.default ⇒ Object
47 48 49 |
# File 'lib/docusign_click/api/accounts_api.rb', line 47 def self.default @@default ||= GetAgreementPdfOptions.new end |