Class: DocuSign_Click::GetClickwrapAgreementsOptions

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/api/accounts_api.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#client_user_idObject

The client user ID to filter to a single user’s agreements.



54
55
56
# File 'lib/docusign_click/api/accounts_api.rb', line 54

def client_user_id
  @client_user_id
end

#from_dateObject

The earliest date to return agreements from.



57
58
59
# File 'lib/docusign_click/api/accounts_api.rb', line 57

def from_date
  @from_date
end

#page_numberObject

The results for this endpoint are paginated. Use this parameter to indicate which page to return. The minimumPagesRemaining value in the response indicates whether to continue querying for additional pages. For example, if the page size is 40: * If this property is set to 0 (the default), the endpoint returns results 1-40. * If this property is set to 1, the endpoint returns results 41-80. The default value is 0.



60
61
62
# File 'lib/docusign_click/api/accounts_api.rb', line 60

def page_number
  @page_number
end

#statusObject

User agreement status. One of: - created - agreed - declined



63
64
65
# File 'lib/docusign_click/api/accounts_api.rb', line 63

def status
  @status
end

#to_dateObject

The latest date to return agreements from.



66
67
68
# File 'lib/docusign_click/api/accounts_api.rb', line 66

def to_date
  @to_date
end

Class Method Details

.defaultObject



68
69
70
# File 'lib/docusign_click/api/accounts_api.rb', line 68

def self.default
  @@default ||= GetClickwrapAgreementsOptions.new
end