Class: DocuSign_Click::UserAgreementResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/models/user_agreement_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ UserAgreementResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/docusign_click/models/user_agreement_response.rb', line 134

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'accountId')
    self. = attributes[:'accountId']
  end

  if attributes.has_key?(:'agreedOn')
    self.agreed_on = attributes[:'agreedOn']
  end

  if attributes.has_key?(:'agreementId')
    self.agreement_id = attributes[:'agreementId']
  end

  if attributes.has_key?(:'agreementUrl')
    self.agreement_url = attributes[:'agreementUrl']
  end

  if attributes.has_key?(:'clickwrapId')
    self.clickwrap_id = attributes[:'clickwrapId']
  end

  if attributes.has_key?(:'clientUserId')
    self.client_user_id = attributes[:'clientUserId']
  end

  if attributes.has_key?(:'consumerDisclosureEnabled')
    self.consumer_disclosure_enabled = attributes[:'consumerDisclosureEnabled']
  end

  if attributes.has_key?(:'consumerDisclosureHtml')
    self.consumer_disclosure_html = attributes[:'consumerDisclosureHtml']
  end

  if attributes.has_key?(:'createdOn')
    self.created_on = attributes[:'createdOn']
  end

  if attributes.has_key?(:'dataFields')
    if (value = attributes[:'dataFields']).is_a?(Array)
      self.data_fields = value
    end
  end

  if attributes.has_key?(:'declinedOn')
    self.declined_on = attributes[:'declinedOn']
  end

  if attributes.has_key?(:'documentData')
    if (value = attributes[:'documentData']).is_a?(Hash)
      self.document_data = value
    end
  end

  if attributes.has_key?(:'documents')
    if (value = attributes[:'documents']).is_a?(Array)
      self.documents = value
    end
  end

  if attributes.has_key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.has_key?(:'returnUrl')
    self.return_url = attributes[:'returnUrl']
  end

  if attributes.has_key?(:'settings')
    self.settings = attributes[:'settings']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'style')
    self.style = attributes[:'style']
  end

  if attributes.has_key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.has_key?(:'versionId')
    self.version_id = attributes[:'versionId']
  end

  if attributes.has_key?(:'versionNumber')
    self.version_number = attributes[:'versionNumber']
  end
end

Instance Attribute Details

#account_idObject

The external account number (int) or account ID GUID.



17
18
19
# File 'lib/docusign_click/models/user_agreement_response.rb', line 17

def 
  @account_id
end

#agreed_onObject

Date that the client last completed the agreement. This property is null if agreementUrl is not null and status is not agreed.



20
21
22
# File 'lib/docusign_click/models/user_agreement_response.rb', line 20

def agreed_on
  @agreed_on
end

#agreement_idObject

The agreement ID.



23
24
25
# File 'lib/docusign_click/models/user_agreement_response.rb', line 23

def agreement_id
  @agreement_id
end

#agreement_urlObject

When not null, an agreement is required for user specified by clientUserId. When missing the user specified by clientUserId has already agreed and does not require a new acceptance. Use this URL to render the agreement in a web page. <!– or redirected to when providing redirect_url as a query parameter. –>



26
27
28
# File 'lib/docusign_click/models/user_agreement_response.rb', line 26

def agreement_url
  @agreement_url
end

#clickwrap_idObject

The ID of the clickwrap.



29
30
31
# File 'lib/docusign_click/models/user_agreement_response.rb', line 29

def clickwrap_id
  @clickwrap_id
end

#client_user_idObject

A unique value that identifies a user.\nYou can use anything that your system uses\nto identify unique users, such as\nemployee IDs, email addresses, and surrogate keys as the value of clientUserId.\n\nA clickwrap with a specific clientUserId will not appear again\nonce it has been accepted.\n"



32
33
34
# File 'lib/docusign_click/models/user_agreement_response.rb', line 32

def client_user_id
  @client_user_id
end

#consumer_disclosure_enabledObject

True if consumer disclosure was required by this agreement.



35
36
37
# File 'lib/docusign_click/models/user_agreement_response.rb', line 35

def consumer_disclosure_enabled
  @consumer_disclosure_enabled
end

#consumer_disclosure_htmlObject

The customer-branded HTML with the Electronic Record and Signature Disclosure information



38
39
40
# File 'lib/docusign_click/models/user_agreement_response.rb', line 38

def consumer_disclosure_html
  @consumer_disclosure_html
end

#created_onObject

The date when the clickwrap was created. May be null.



41
42
43
# File 'lib/docusign_click/models/user_agreement_response.rb', line 41

def created_on
  @created_on
end

#data_fieldsObject

The list of all the data fields available for the clickwrap (custom fields and standard fields).



44
45
46
# File 'lib/docusign_click/models/user_agreement_response.rb', line 44

def data_fields
  @data_fields
end

#declined_onObject

The date when the user declined the most recent required agreement. This property is valid only when status is declined. Otherwise it is null.



47
48
49
# File 'lib/docusign_click/models/user_agreement_response.rb', line 47

def declined_on
  @declined_on
end

#document_dataObject

This property specifies the data used to create a clickwrap with [dynamic content][]. [dynamic content]: /docs/click-api/click101/customize-clickwrap-fields/#embed-clickwraps-that-contain-dynamic-content



50
51
52
# File 'lib/docusign_click/models/user_agreement_response.rb', line 50

def document_data
  @document_data
end

#documentsObject

An array of documents.



53
54
55
# File 'lib/docusign_click/models/user_agreement_response.rb', line 53

def documents
  @documents
end

#metadataObject

A customer-defined string you can use in requests. This string will appear in the corresponding response.



56
57
58
# File 'lib/docusign_click/models/user_agreement_response.rb', line 56

def 
  
end

#return_urlObject

The URL redirected to after the agreement was completed.



59
60
61
# File 'lib/docusign_click/models/user_agreement_response.rb', line 59

def return_url
  @return_url
end

#settingsObject

The display settings for this agreement.



62
63
64
# File 'lib/docusign_click/models/user_agreement_response.rb', line 62

def settings
  @settings
end

#statusObject

User agreement status. One of: - created - agreed - declined



65
66
67
# File 'lib/docusign_click/models/user_agreement_response.rb', line 65

def status
  @status
end

#styleObject

Returns the value of attribute style.



67
68
69
# File 'lib/docusign_click/models/user_agreement_response.rb', line 67

def style
  @style
end

#versionObject

The human-readable semver version string.



70
71
72
# File 'lib/docusign_click/models/user_agreement_response.rb', line 70

def version
  @version
end

#version_idObject

The ID of the version.



73
74
75
# File 'lib/docusign_click/models/user_agreement_response.rb', line 73

def version_id
  @version_id
end

#version_numberObject

Version of the clickwrap.



76
77
78
# File 'lib/docusign_click/models/user_agreement_response.rb', line 76

def version_number
  @version_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/docusign_click/models/user_agreement_response.rb', line 79

def self.attribute_map
  {
    :'account_id' => :'accountId',
    :'agreed_on' => :'agreedOn',
    :'agreement_id' => :'agreementId',
    :'agreement_url' => :'agreementUrl',
    :'clickwrap_id' => :'clickwrapId',
    :'client_user_id' => :'clientUserId',
    :'consumer_disclosure_enabled' => :'consumerDisclosureEnabled',
    :'consumer_disclosure_html' => :'consumerDisclosureHtml',
    :'created_on' => :'createdOn',
    :'data_fields' => :'dataFields',
    :'declined_on' => :'declinedOn',
    :'document_data' => :'documentData',
    :'documents' => :'documents',
    :'metadata' => :'metadata',
    :'return_url' => :'returnUrl',
    :'settings' => :'settings',
    :'status' => :'status',
    :'style' => :'style',
    :'version' => :'version',
    :'version_id' => :'versionId',
    :'version_number' => :'versionNumber'
  }
end

.swagger_typesObject

Attribute type mapping.



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/docusign_click/models/user_agreement_response.rb', line 106

def self.swagger_types
  {
    :'account_id' => :'String',
    :'agreed_on' => :'Object',
    :'agreement_id' => :'String',
    :'agreement_url' => :'String',
    :'clickwrap_id' => :'String',
    :'client_user_id' => :'String',
    :'consumer_disclosure_enabled' => :'BOOLEAN',
    :'consumer_disclosure_html' => :'String',
    :'created_on' => :'Object',
    :'data_fields' => :'Array<DataField>',
    :'declined_on' => :'Object',
    :'document_data' => :'Hash<String, String>',
    :'documents' => :'Array<Document>',
    :'metadata' => :'String',
    :'return_url' => :'String',
    :'settings' => :'DisplaySettings',
    :'status' => :'String',
    :'style' => :'UserAgreementResponseStyle',
    :'version' => :'String',
    :'version_id' => :'String',
    :'version_number' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/docusign_click/models/user_agreement_response.rb', line 246

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
      agreed_on == o.agreed_on &&
      agreement_id == o.agreement_id &&
      agreement_url == o.agreement_url &&
      clickwrap_id == o.clickwrap_id &&
      client_user_id == o.client_user_id &&
      consumer_disclosure_enabled == o.consumer_disclosure_enabled &&
      consumer_disclosure_html == o.consumer_disclosure_html &&
      created_on == o.created_on &&
      data_fields == o.data_fields &&
      declined_on == o.declined_on &&
      document_data == o.document_data &&
      documents == o.documents &&
       == o. &&
      return_url == o.return_url &&
      settings == o.settings &&
      status == o.status &&
      style == o.style &&
      version == o.version &&
      version_id == o.version_id &&
      version_number == o.version_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/docusign_click/models/user_agreement_response.rb', line 308

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_Click.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/docusign_click/models/user_agreement_response.rb', line 374

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/docusign_click/models/user_agreement_response.rb', line 287

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


274
275
276
# File 'lib/docusign_click/models/user_agreement_response.rb', line 274

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



280
281
282
# File 'lib/docusign_click/models/user_agreement_response.rb', line 280

def hash
  [, agreed_on, agreement_id, agreement_url, clickwrap_id, client_user_id, consumer_disclosure_enabled, consumer_disclosure_html, created_on, data_fields, declined_on, document_data, documents, , return_url, settings, status, style, version, version_id, version_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



233
234
235
236
# File 'lib/docusign_click/models/user_agreement_response.rb', line 233

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
# File 'lib/docusign_click/models/user_agreement_response.rb', line 354

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
# File 'lib/docusign_click/models/user_agreement_response.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



348
349
350
# File 'lib/docusign_click/models/user_agreement_response.rb', line 348

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



240
241
242
# File 'lib/docusign_click/models/user_agreement_response.rb', line 240

def valid?
  true
end