Class: DocuSign_Click::AccountsApi
- Inherits:
-
Object
- Object
- DocuSign_Click::AccountsApi
- Defined in:
- lib/docusign_click/api/accounts_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_clickwrap(account_id, clickwrap_request) ⇒ ClickwrapVersionSummaryResponse
Creates a Clickwrap for the specified accountId.
-
#create_clickwrap_version(account_id, clickwrap_id, clickwrap_request) ⇒ ClickwrapVersionSummaryResponse
Creates the clickwrap version.
-
#create_clickwrap_version_with_http_info(account_id, clickwrap_id, clickwrap_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Creates the clickwrap version.
-
#create_clickwrap_with_http_info(account_id, clickwrap_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Creates a Clickwrap for the specified accountId.
-
#create_has_agreed(account_id, clickwrap_id, user_agreement_request) ⇒ UserAgreementResponse
Checks if a user has agreed to a clickwrap and returns a response with the agreement url.
-
#create_has_agreed_with_http_info(account_id, clickwrap_id, user_agreement_request) ⇒ Array<(UserAgreementResponse, Fixnum, Hash)>
Checks if a user has agreed to a clickwrap and returns a response with the agreement url.
-
#delete_clickwrap(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapOptions.default) ⇒ ClickwrapVersionsDeleteResponse
Deletes the clickwrap and all its version specified by clickwrapId.
-
#delete_clickwrap_version(account_id, clickwrap_id, version_id) ⇒ ClickwrapVersionDeleteResponse
Delete a Clickwrap version specified by versionId.
-
#delete_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) ⇒ Array<(ClickwrapVersionDeleteResponse, Fixnum, Hash)>
Delete a Clickwrap version specified by versionId.
-
#delete_clickwrap_versions(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapVersionsOptions.default) ⇒ ClickwrapVersionsDeleteResponse
Deletes the versions specified by query parameter clickwrapVersionIds for a clickwrap, or all versions if no query parameter is specified.
-
#delete_clickwrap_versions_with_http_info(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapVersionsOptions.default) ⇒ Array<(ClickwrapVersionsDeleteResponse, Fixnum, Hash)>
Deletes the versions specified by query parameter clickwrapVersionIds for a clickwrap, or all versions if no query parameter is specified.
-
#delete_clickwrap_with_http_info(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapOptions.default) ⇒ Array<(ClickwrapVersionsDeleteResponse, Fixnum, Hash)>
Deletes the clickwrap and all its version specified by clickwrapId.
-
#delete_clickwraps(account_id, options = DocuSign_Click::DeleteClickwrapsOptions.default) ⇒ ClickwrapsDeleteResponse
Deletes all the clickwraps for an account or the ones passed in query parameter clickwrapIds.
-
#delete_clickwraps_with_http_info(account_id, options = DocuSign_Click::DeleteClickwrapsOptions.default) ⇒ Array<(ClickwrapsDeleteResponse, Fixnum, Hash)>
Deletes all the clickwraps for an account or the ones passed in query parameter clickwrapIds.
-
#get_agreement(account_id, agreement_id, clickwrap_id) ⇒ UserAgreementResponse
Gets the agreement by a provided agreement ID.
-
#get_agreement_document(account_id, clickwrap_id, order_or_disclosure, version_id) ⇒ Document
Downloads a document at an order within the agreement.
-
#get_agreement_document_with_http_info(account_id, clickwrap_id, order_or_disclosure, version_id) ⇒ Array<(Document, Fixnum, Hash)>
Downloads a document at an order within the agreement.
-
#get_agreement_pdf(account_id, agreement_id, clickwrap_id, options = DocuSign_Click::GetAgreementPdfOptions.default) ⇒ File
Downloads the agreement PDF and optionally certificate of completion.
-
#get_agreement_pdf_with_http_info(account_id, agreement_id, clickwrap_id, options = DocuSign_Click::GetAgreementPdfOptions.default) ⇒ Array<(File, Fixnum, Hash)>
Downloads the agreement PDF and optionally certificate of completion.
-
#get_agreement_with_http_info(account_id, agreement_id, clickwrap_id) ⇒ Array<(UserAgreementResponse, Fixnum, Hash)>
Gets the agreement by a provided agreement ID.
-
#get_clickwrap(account_id, clickwrap_id) ⇒ ClickwrapVersionResponse
Gets the clickwrap for an account specified by clickwrapId.
-
#get_clickwrap_agreements(account_id, clickwrap_id, options = DocuSign_Click::GetClickwrapAgreementsOptions.default) ⇒ ClickwrapAgreementsResponse
Gets the agreement responses for a clickwrap.
-
#get_clickwrap_agreements_with_http_info(account_id, clickwrap_id, options = DocuSign_Click::GetClickwrapAgreementsOptions.default) ⇒ Array<(ClickwrapAgreementsResponse, Fixnum, Hash)>
Gets the agreement responses for a clickwrap.
-
#get_clickwrap_version(account_id, clickwrap_id, version_id) ⇒ ClickwrapVersionResponse
Gets the Clickwrap version by clickwrapId and versionId for an account.
-
#get_clickwrap_version_agreements(account_id, clickwrap_id, version_id, options = DocuSign_Click::GetClickwrapVersionAgreementsOptions.default) ⇒ ClickwrapAgreementsResponse
Gets the agreement responses for a clickwrap version.
-
#get_clickwrap_version_agreements_with_http_info(account_id, clickwrap_id, version_id, options = DocuSign_Click::GetClickwrapVersionAgreementsOptions.default) ⇒ Array<(ClickwrapAgreementsResponse, Fixnum, Hash)>
Gets the agreement responses for a clickwrap version.
-
#get_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) ⇒ Array<(ClickwrapVersionResponse, Fixnum, Hash)>
Gets the Clickwrap version by clickwrapId and versionId for an account.
-
#get_clickwrap_versions(account_id, clickwrap_id) ⇒ ClickwrapVersionsPagedResponse
Gets all the versions of a clickwrap for an account.
-
#get_clickwrap_versions_with_http_info(account_id, clickwrap_id) ⇒ Array<(ClickwrapVersionsPagedResponse, Fixnum, Hash)>
Gets all the versions of a clickwrap for an account.
-
#get_clickwrap_with_http_info(account_id, clickwrap_id) ⇒ Array<(ClickwrapVersionResponse, Fixnum, Hash)>
Gets the clickwrap for an account specified by clickwrapId.
-
#get_clickwraps(account_id, options = DocuSign_Click::GetClickwrapsOptions.default) ⇒ ClickwrapVersionsResponse
Gets the Clickwraps for an account.
-
#get_clickwraps_with_http_info(account_id, options = DocuSign_Click::GetClickwrapsOptions.default) ⇒ Array<(ClickwrapVersionsResponse, Fixnum, Hash)>
Gets the Clickwraps for an account.
-
#get_service_information ⇒ ServiceInformation
Provides base service and version access information.
-
#get_service_information_with_http_info ⇒ Array<(ServiceInformation, Fixnum, Hash)>
Provides base service and version access information.
-
#initialize(api_client = AccountsApi.default) ⇒ AccountsApi
constructor
A new instance of AccountsApi.
-
#update_clickwrap(account_id, clickwrap_id, clickwrap_transfer_request) ⇒ ClickwrapVersionSummaryResponse
Updates the clickwrap specified by clickwrapId.
-
#update_clickwrap_version(account_id, clickwrap_id, version_id, clickwrap_request) ⇒ ClickwrapVersionSummaryResponse
Updates the clickwrap version specified by versionId.
-
#update_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id, clickwrap_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Updates the clickwrap version specified by versionId.
-
#update_clickwrap_with_http_info(account_id, clickwrap_id, clickwrap_transfer_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Updates the clickwrap specified by clickwrapId.
Constructor Details
#initialize(api_client = AccountsApi.default) ⇒ AccountsApi
Returns a new instance of AccountsApi.
125 126 127 |
# File 'lib/docusign_click/api/accounts_api.rb', line 125 def initialize(api_client = AccountsApi.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
123 124 125 |
# File 'lib/docusign_click/api/accounts_api.rb', line 123 def api_client @api_client end |
Instance Method Details
#create_clickwrap(account_id, clickwrap_request) ⇒ ClickwrapVersionSummaryResponse
Creates a Clickwrap for the specified accountId
134 135 136 137 |
# File 'lib/docusign_click/api/accounts_api.rb', line 134 def create_clickwrap(account_id, clickwrap_request) data, _status_code, _headers = create_clickwrap_with_http_info(account_id, clickwrap_request) return data end |
#create_clickwrap_version(account_id, clickwrap_id, clickwrap_request) ⇒ ClickwrapVersionSummaryResponse
Creates the clickwrap version
186 187 188 189 |
# File 'lib/docusign_click/api/accounts_api.rb', line 186 def create_clickwrap_version(account_id, clickwrap_id, clickwrap_request) data, _status_code, _headers = create_clickwrap_version_with_http_info(account_id, clickwrap_id, clickwrap_request) return data end |
#create_clickwrap_version_with_http_info(account_id, clickwrap_id, clickwrap_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Creates the clickwrap version
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/docusign_click/api/accounts_api.rb', line 197 def create_clickwrap_version_with_http_info(account_id, clickwrap_id, clickwrap_request) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.create_clickwrap_version ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.create_clickwrap_version" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.create_clickwrap_version" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(clickwrap_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionSummaryResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#create_clickwrap_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_clickwrap_with_http_info(account_id, clickwrap_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Creates a Clickwrap for the specified accountId
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/docusign_click/api/accounts_api.rb', line 144 def create_clickwrap_with_http_info(account_id, clickwrap_request) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.create_clickwrap ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.create_clickwrap" if account_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(clickwrap_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionSummaryResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#create_clickwrap\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_has_agreed(account_id, clickwrap_id, user_agreement_request) ⇒ UserAgreementResponse
Checks if a user has agreed to a clickwrap and returns a response with the agreement url. Returns HttpStatusCode.OK if user has no pending agreement.
241 242 243 244 |
# File 'lib/docusign_click/api/accounts_api.rb', line 241 def create_has_agreed(account_id, clickwrap_id, user_agreement_request) data, _status_code, _headers = create_has_agreed_with_http_info(account_id, clickwrap_id, user_agreement_request) return data end |
#create_has_agreed_with_http_info(account_id, clickwrap_id, user_agreement_request) ⇒ Array<(UserAgreementResponse, Fixnum, Hash)>
Checks if a user has agreed to a clickwrap and returns a response with the agreement url. Returns HttpStatusCode.OK if user has no pending agreement.
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/docusign_click/api/accounts_api.rb', line 252 def create_has_agreed_with_http_info(account_id, clickwrap_id, user_agreement_request) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.create_has_agreed ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.create_has_agreed" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.create_has_agreed" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/agreements".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(user_agreement_request) auth_names = [] data, status_code, headers = @api_client.call_api(:POST, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UserAgreementResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#create_has_agreed\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_clickwrap(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapOptions.default) ⇒ ClickwrapVersionsDeleteResponse
Deletes the clickwrap and all its version specified by clickwrapId. Active clickwrap will not get deleted
296 297 298 299 |
# File 'lib/docusign_click/api/accounts_api.rb', line 296 def delete_clickwrap(account_id, clickwrap_id, = DocuSign_Click::DeleteClickwrapOptions.default) data, _status_code, _headers = delete_clickwrap_with_http_info(account_id, clickwrap_id, ) return data end |
#delete_clickwrap_version(account_id, clickwrap_id, version_id) ⇒ ClickwrapVersionDeleteResponse
Delete a Clickwrap version specified by versionId
352 353 354 355 |
# File 'lib/docusign_click/api/accounts_api.rb', line 352 def delete_clickwrap_version(account_id, clickwrap_id, version_id) data, _status_code, _headers = delete_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) return data end |
#delete_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) ⇒ Array<(ClickwrapVersionDeleteResponse, Fixnum, Hash)>
Delete a Clickwrap version specified by versionId
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/docusign_click/api/accounts_api.rb', line 363 def delete_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.delete_clickwrap_version ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.delete_clickwrap_version" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.delete_clickwrap_version" if clickwrap_id.nil? # verify the required parameter 'version_id' is set fail ArgumentError, "Missing the required parameter 'version_id' when calling AccountsApi.delete_clickwrap_version" if version_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions/{versionId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s).sub('{' + 'versionId' + '}', version_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionDeleteResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#delete_clickwrap_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_clickwrap_versions(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapVersionsOptions.default) ⇒ ClickwrapVersionsDeleteResponse
Deletes the versions specified by query parameter clickwrapVersionIds for a clickwrap, or all versions if no query parameter is specified. It will not delete if a version is active.
409 410 411 412 |
# File 'lib/docusign_click/api/accounts_api.rb', line 409 def delete_clickwrap_versions(account_id, clickwrap_id, = DocuSign_Click::DeleteClickwrapVersionsOptions.default) data, _status_code, _headers = delete_clickwrap_versions_with_http_info(account_id, clickwrap_id, ) return data end |
#delete_clickwrap_versions_with_http_info(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapVersionsOptions.default) ⇒ Array<(ClickwrapVersionsDeleteResponse, Fixnum, Hash)>
Deletes the versions specified by query parameter clickwrapVersionIds for a clickwrap, or all versions if no query parameter is specified. It will not delete if a version is active.
420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 |
# File 'lib/docusign_click/api/accounts_api.rb', line 420 def delete_clickwrap_versions_with_http_info(account_id, clickwrap_id, = DocuSign_Click::DeleteClickwrapVersionsOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.delete_clickwrap_versions ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.delete_clickwrap_versions" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.delete_clickwrap_versions" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} query_params[:'clickwrapVersionIds'] = .clickwrap_version_ids if !.clickwrap_version_ids.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionsDeleteResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#delete_clickwrap_versions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_clickwrap_with_http_info(account_id, clickwrap_id, options = DocuSign_Click::DeleteClickwrapOptions.default) ⇒ Array<(ClickwrapVersionsDeleteResponse, Fixnum, Hash)>
Deletes the clickwrap and all its version specified by clickwrapId. Active clickwrap will not get deleted
307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/docusign_click/api/accounts_api.rb', line 307 def delete_clickwrap_with_http_info(account_id, clickwrap_id, = DocuSign_Click::DeleteClickwrapOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.delete_clickwrap ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.delete_clickwrap" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.delete_clickwrap" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} query_params[:'versions'] = .versions if !.versions.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionsDeleteResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#delete_clickwrap\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_clickwraps(account_id, options = DocuSign_Click::DeleteClickwrapsOptions.default) ⇒ ClickwrapsDeleteResponse
Deletes all the clickwraps for an account or the ones passed in query parameter clickwrapIds. It will not delete active clickwraps.
464 465 466 467 |
# File 'lib/docusign_click/api/accounts_api.rb', line 464 def delete_clickwraps(account_id, = DocuSign_Click::DeleteClickwrapsOptions.default) data, _status_code, _headers = delete_clickwraps_with_http_info(account_id, ) return data end |
#delete_clickwraps_with_http_info(account_id, options = DocuSign_Click::DeleteClickwrapsOptions.default) ⇒ Array<(ClickwrapsDeleteResponse, Fixnum, Hash)>
Deletes all the clickwraps for an account or the ones passed in query parameter clickwrapIds. It will not delete active clickwraps.
474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 |
# File 'lib/docusign_click/api/accounts_api.rb', line 474 def delete_clickwraps_with_http_info(account_id, = DocuSign_Click::DeleteClickwrapsOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.delete_clickwraps ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.delete_clickwraps" if account_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s) # query parameters query_params = {} query_params[:'clickwrapIds'] = .clickwrap_ids if !.clickwrap_ids.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapsDeleteResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#delete_clickwraps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_agreement(account_id, agreement_id, clickwrap_id) ⇒ UserAgreementResponse
Gets the agreement by a provided agreement ID
517 518 519 520 |
# File 'lib/docusign_click/api/accounts_api.rb', line 517 def get_agreement(account_id, agreement_id, clickwrap_id) data, _status_code, _headers = get_agreement_with_http_info(account_id, agreement_id, clickwrap_id) return data end |
#get_agreement_document(account_id, clickwrap_id, order_or_disclosure, version_id) ⇒ Document
Downloads a document at an order within the agreement.
575 576 577 578 |
# File 'lib/docusign_click/api/accounts_api.rb', line 575 def get_agreement_document(account_id, clickwrap_id, order_or_disclosure, version_id) data, _status_code, _headers = get_agreement_document_with_http_info(account_id, clickwrap_id, order_or_disclosure, version_id) return data end |
#get_agreement_document_with_http_info(account_id, clickwrap_id, order_or_disclosure, version_id) ⇒ Array<(Document, Fixnum, Hash)>
Downloads a document at an order within the agreement.
587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 |
# File 'lib/docusign_click/api/accounts_api.rb', line 587 def get_agreement_document_with_http_info(account_id, clickwrap_id, order_or_disclosure, version_id) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_agreement_document ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_agreement_document" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_agreement_document" if clickwrap_id.nil? # verify the required parameter 'order_or_disclosure' is set fail ArgumentError, "Missing the required parameter 'order_or_disclosure' when calling AccountsApi.get_agreement_document" if order_or_disclosure.nil? # verify the required parameter 'version_id' is set fail ArgumentError, "Missing the required parameter 'version_id' when calling AccountsApi.get_agreement_document" if version_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions/{versionId}/documents/{orderOrDisclosure}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s).sub('{' + 'orderOrDisclosure' + '}', order_or_disclosure.to_s).sub('{' + 'versionId' + '}', version_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'Document') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_agreement_document\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_agreement_pdf(account_id, agreement_id, clickwrap_id, options = DocuSign_Click::GetAgreementPdfOptions.default) ⇒ File
Downloads the agreement PDF and optionally certificate of completion.
636 637 638 639 |
# File 'lib/docusign_click/api/accounts_api.rb', line 636 def get_agreement_pdf(account_id, agreement_id, clickwrap_id, = DocuSign_Click::GetAgreementPdfOptions.default) data, _status_code, _headers = get_agreement_pdf_with_http_info(account_id, agreement_id, clickwrap_id, ) return data end |
#get_agreement_pdf_with_http_info(account_id, agreement_id, clickwrap_id, options = DocuSign_Click::GetAgreementPdfOptions.default) ⇒ Array<(File, Fixnum, Hash)>
Downloads the agreement PDF and optionally certificate of completion.
648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/docusign_click/api/accounts_api.rb', line 648 def get_agreement_pdf_with_http_info(account_id, agreement_id, clickwrap_id, = DocuSign_Click::GetAgreementPdfOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_agreement_pdf ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_agreement_pdf" if account_id.nil? # verify the required parameter 'agreement_id' is set fail ArgumentError, "Missing the required parameter 'agreement_id' when calling AccountsApi.get_agreement_pdf" if agreement_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_agreement_pdf" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/agreements/{agreementId}/download".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'agreementId' + '}', agreement_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} query_params[:'include_coc'] = .include_coc if !.include_coc.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/pdf']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'File') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_agreement_pdf\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_agreement_with_http_info(account_id, agreement_id, clickwrap_id) ⇒ Array<(UserAgreementResponse, Fixnum, Hash)>
Gets the agreement by a provided agreement ID
528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/docusign_click/api/accounts_api.rb', line 528 def get_agreement_with_http_info(account_id, agreement_id, clickwrap_id) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_agreement ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_agreement" if account_id.nil? # verify the required parameter 'agreement_id' is set fail ArgumentError, "Missing the required parameter 'agreement_id' when calling AccountsApi.get_agreement" if agreement_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_agreement" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/agreements/{agreementId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'agreementId' + '}', agreement_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'UserAgreementResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_agreement\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_clickwrap(account_id, clickwrap_id) ⇒ ClickwrapVersionResponse
Gets the clickwrap for an account specified by clickwrapId
694 695 696 697 |
# File 'lib/docusign_click/api/accounts_api.rb', line 694 def get_clickwrap(account_id, clickwrap_id) data, _status_code, _headers = get_clickwrap_with_http_info(account_id, clickwrap_id) return data end |
#get_clickwrap_agreements(account_id, clickwrap_id, options = DocuSign_Click::GetClickwrapAgreementsOptions.default) ⇒ ClickwrapAgreementsResponse
Gets the agreement responses for a clickwrap
748 749 750 751 |
# File 'lib/docusign_click/api/accounts_api.rb', line 748 def get_clickwrap_agreements(account_id, clickwrap_id, = DocuSign_Click::GetClickwrapAgreementsOptions.default) data, _status_code, _headers = get_clickwrap_agreements_with_http_info(account_id, clickwrap_id, ) return data end |
#get_clickwrap_agreements_with_http_info(account_id, clickwrap_id, options = DocuSign_Click::GetClickwrapAgreementsOptions.default) ⇒ Array<(ClickwrapAgreementsResponse, Fixnum, Hash)>
Gets the agreement responses for a clickwrap
759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 |
# File 'lib/docusign_click/api/accounts_api.rb', line 759 def get_clickwrap_agreements_with_http_info(account_id, clickwrap_id, = DocuSign_Click::GetClickwrapAgreementsOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_clickwrap_agreements ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_clickwrap_agreements" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_clickwrap_agreements" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/users".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} query_params[:'client_user_id'] = .client_user_id if !.client_user_id.nil? query_params[:'from_date'] = .from_date if !.from_date.nil? query_params[:'page_number'] = .page_number if !.page_number.nil? query_params[:'status'] = .status if !.status.nil? query_params[:'to_date'] = .to_date if !.to_date.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapAgreementsResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_clickwrap_agreements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_clickwrap_version(account_id, clickwrap_id, version_id) ⇒ ClickwrapVersionResponse
Gets the Clickwrap version by clickwrapId and versionId for an account
808 809 810 811 |
# File 'lib/docusign_click/api/accounts_api.rb', line 808 def get_clickwrap_version(account_id, clickwrap_id, version_id) data, _status_code, _headers = get_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) return data end |
#get_clickwrap_version_agreements(account_id, clickwrap_id, version_id, options = DocuSign_Click::GetClickwrapVersionAgreementsOptions.default) ⇒ ClickwrapAgreementsResponse
Gets the agreement responses for a clickwrap version
866 867 868 869 |
# File 'lib/docusign_click/api/accounts_api.rb', line 866 def get_clickwrap_version_agreements(account_id, clickwrap_id, version_id, = DocuSign_Click::GetClickwrapVersionAgreementsOptions.default) data, _status_code, _headers = get_clickwrap_version_agreements_with_http_info(account_id, clickwrap_id, version_id, ) return data end |
#get_clickwrap_version_agreements_with_http_info(account_id, clickwrap_id, version_id, options = DocuSign_Click::GetClickwrapVersionAgreementsOptions.default) ⇒ Array<(ClickwrapAgreementsResponse, Fixnum, Hash)>
Gets the agreement responses for a clickwrap version
878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 |
# File 'lib/docusign_click/api/accounts_api.rb', line 878 def get_clickwrap_version_agreements_with_http_info(account_id, clickwrap_id, version_id, = DocuSign_Click::GetClickwrapVersionAgreementsOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_clickwrap_version_agreements ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_clickwrap_version_agreements" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_clickwrap_version_agreements" if clickwrap_id.nil? # verify the required parameter 'version_id' is set fail ArgumentError, "Missing the required parameter 'version_id' when calling AccountsApi.get_clickwrap_version_agreements" if version_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions/{versionId}/users".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s).sub('{' + 'versionId' + '}', version_id.to_s) # query parameters query_params = {} query_params[:'client_user_id'] = .client_user_id if !.client_user_id.nil? query_params[:'from_date'] = .from_date if !.from_date.nil? query_params[:'page_number'] = .page_number if !.page_number.nil? query_params[:'status'] = .status if !.status.nil? query_params[:'to_date'] = .to_date if !.to_date.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapAgreementsResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_clickwrap_version_agreements\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) ⇒ Array<(ClickwrapVersionResponse, Fixnum, Hash)>
Gets the Clickwrap version by clickwrapId and versionId for an account
819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 |
# File 'lib/docusign_click/api/accounts_api.rb', line 819 def get_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_clickwrap_version ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_clickwrap_version" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_clickwrap_version" if clickwrap_id.nil? # verify the required parameter 'version_id' is set fail ArgumentError, "Missing the required parameter 'version_id' when calling AccountsApi.get_clickwrap_version" if version_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions/{versionId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s).sub('{' + 'versionId' + '}', version_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_clickwrap_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_clickwrap_versions(account_id, clickwrap_id) ⇒ ClickwrapVersionsPagedResponse
Gets all the versions of a clickwrap for an account
928 929 930 931 |
# File 'lib/docusign_click/api/accounts_api.rb', line 928 def get_clickwrap_versions(account_id, clickwrap_id) data, _status_code, _headers = get_clickwrap_versions_with_http_info(account_id, clickwrap_id) return data end |
#get_clickwrap_versions_with_http_info(account_id, clickwrap_id) ⇒ Array<(ClickwrapVersionsPagedResponse, Fixnum, Hash)>
Gets all the versions of a clickwrap for an account
938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 |
# File 'lib/docusign_click/api/accounts_api.rb', line 938 def get_clickwrap_versions_with_http_info(account_id, clickwrap_id) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_clickwrap_versions ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_clickwrap_versions" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_clickwrap_versions" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionsPagedResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_clickwrap_versions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_clickwrap_with_http_info(account_id, clickwrap_id) ⇒ Array<(ClickwrapVersionResponse, Fixnum, Hash)>
Gets the clickwrap for an account specified by clickwrapId
704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 |
# File 'lib/docusign_click/api/accounts_api.rb', line 704 def get_clickwrap_with_http_info(account_id, clickwrap_id) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_clickwrap ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_clickwrap" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.get_clickwrap" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_clickwrap\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_clickwraps(account_id, options = DocuSign_Click::GetClickwrapsOptions.default) ⇒ ClickwrapVersionsResponse
Gets the Clickwraps for an account
981 982 983 984 |
# File 'lib/docusign_click/api/accounts_api.rb', line 981 def get_clickwraps(account_id, = DocuSign_Click::GetClickwrapsOptions.default) data, _status_code, _headers = get_clickwraps_with_http_info(account_id, ) return data end |
#get_clickwraps_with_http_info(account_id, options = DocuSign_Click::GetClickwrapsOptions.default) ⇒ Array<(ClickwrapVersionsResponse, Fixnum, Hash)>
Gets the Clickwraps for an account
991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 |
# File 'lib/docusign_click/api/accounts_api.rb', line 991 def get_clickwraps_with_http_info(account_id, = DocuSign_Click::GetClickwrapsOptions.default) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_clickwraps ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.get_clickwraps" if account_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s) # query parameters query_params = {} query_params[:'filter'] = .filter if !.filter.nil? query_params[:'from_date'] = .from_date if !.from_date.nil? query_params[:'name'] = .name if !.name.nil? query_params[:'ownerUserId'] = .owner_user_id if !.owner_user_id.nil? query_params[:'page_number'] = .page_number if !.page_number.nil? query_params[:'status'] = .status if !.status.nil? query_params[:'to_date'] = .to_date if !.to_date.nil? # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionsResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_clickwraps\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_service_information ⇒ ServiceInformation
Provides base service and version access information.
1037 1038 1039 1040 |
# File 'lib/docusign_click/api/accounts_api.rb', line 1037 def get_service_information() data, _status_code, _headers = get_service_information_with_http_info() return data end |
#get_service_information_with_http_info ⇒ Array<(ServiceInformation, Fixnum, Hash)>
Provides base service and version access information.
1045 1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 1067 1068 1069 1070 1071 1072 1073 1074 1075 1076 1077 |
# File 'lib/docusign_click/api/accounts_api.rb', line 1045 def get_service_information_with_http_info() if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.get_service_information ..." end # resource path local_var_path = "/service_information".sub('{format}','json') # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = [] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ServiceInformation') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#get_service_information\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_clickwrap(account_id, clickwrap_id, clickwrap_transfer_request) ⇒ ClickwrapVersionSummaryResponse
Updates the clickwrap specified by clickwrapId
1085 1086 1087 1088 |
# File 'lib/docusign_click/api/accounts_api.rb', line 1085 def update_clickwrap(account_id, clickwrap_id, clickwrap_transfer_request) data, _status_code, _headers = update_clickwrap_with_http_info(account_id, clickwrap_id, clickwrap_transfer_request) return data end |
#update_clickwrap_version(account_id, clickwrap_id, version_id, clickwrap_request) ⇒ ClickwrapVersionSummaryResponse
Updates the clickwrap version specified by versionId
1141 1142 1143 1144 |
# File 'lib/docusign_click/api/accounts_api.rb', line 1141 def update_clickwrap_version(account_id, clickwrap_id, version_id, clickwrap_request) data, _status_code, _headers = update_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id, clickwrap_request) return data end |
#update_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id, clickwrap_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Updates the clickwrap version specified by versionId
1153 1154 1155 1156 1157 1158 1159 1160 1161 1162 1163 1164 1165 1166 1167 1168 1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 |
# File 'lib/docusign_click/api/accounts_api.rb', line 1153 def update_clickwrap_version_with_http_info(account_id, clickwrap_id, version_id, clickwrap_request) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.update_clickwrap_version ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.update_clickwrap_version" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.update_clickwrap_version" if clickwrap_id.nil? # verify the required parameter 'version_id' is set fail ArgumentError, "Missing the required parameter 'version_id' when calling AccountsApi.update_clickwrap_version" if version_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}/versions/{versionId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s).sub('{' + 'versionId' + '}', version_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(clickwrap_request) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionSummaryResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#update_clickwrap_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_clickwrap_with_http_info(account_id, clickwrap_id, clickwrap_transfer_request) ⇒ Array<(ClickwrapVersionSummaryResponse, Fixnum, Hash)>
Updates the clickwrap specified by clickwrapId
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 1132 |
# File 'lib/docusign_click/api/accounts_api.rb', line 1096 def update_clickwrap_with_http_info(account_id, clickwrap_id, clickwrap_transfer_request) if @api_client.config.debugging @api_client.config.logger.debug "Calling API: AccountsApi.update_clickwrap ..." end # verify the required parameter 'account_id' is set fail ArgumentError, "Missing the required parameter 'account_id' when calling AccountsApi.update_clickwrap" if account_id.nil? # verify the required parameter 'clickwrap_id' is set fail ArgumentError, "Missing the required parameter 'clickwrap_id' when calling AccountsApi.update_clickwrap" if clickwrap_id.nil? # resource path local_var_path = "/v1/accounts/{accountId}/clickwraps/{clickwrapId}".sub('{format}','json').sub('{' + 'accountId' + '}', account_id.to_s).sub('{' + 'clickwrapId' + '}', clickwrap_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = @api_client.object_to_http_body(clickwrap_transfer_request) auth_names = [] data, status_code, headers = @api_client.call_api(:PUT, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'ClickwrapVersionSummaryResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: AccountsApi#update_clickwrap\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |