Class: DocuSign_Click::ClickwrapRequest

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/models/clickwrap_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClickwrapRequest

Initializes the object

Parameters:

  • (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/docusign_click/models/clickwrap_request.rb', line 93

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'clickwrapName')
    self.clickwrap_name = attributes[:'clickwrapName']
  end

  if attributes.has_key?(:'displaySettings')
    self.display_settings = attributes[:'displaySettings']
  end

  if attributes.has_key?(:'documents')
    if (value = attributes[:'documents']).is_a?(Array)
      self.documents = value
    end
  end

  if attributes.has_key?(:'fieldsToNull')
    self.fields_to_null = attributes[:'fieldsToNull']
  end

  if attributes.has_key?(:'isMajorVersion')
    self.is_major_version = attributes[:'isMajorVersion']
  end

  if attributes.has_key?(:'isShared')
    self.is_shared = attributes[:'isShared']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'requireReacceptance')
    self.require_reacceptance = attributes[:'requireReacceptance']
  end

  if attributes.has_key?(:'scheduledDate')
    self.scheduled_date = attributes[:'scheduledDate']
  end

  if attributes.has_key?(:'scheduledReacceptance')
    self.scheduled_reacceptance = attributes[:'scheduledReacceptance']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'transferFromUserId')
    self.transfer_from_user_id = attributes[:'transferFromUserId']
  end

  if attributes.has_key?(:'transferToUserId')
    self.transfer_to_user_id = attributes[:'transferToUserId']
  end
end

Instance Attribute Details

#clickwrap_nameObject

Returns the value of attribute clickwrap_name.



17
18
19
# File 'lib/docusign_click/models/clickwrap_request.rb', line 17

def clickwrap_name
  @clickwrap_name
end

#display_settingsObject

Returns the value of attribute display_settings.



19
20
21
# File 'lib/docusign_click/models/clickwrap_request.rb', line 19

def display_settings
  @display_settings
end

#documentsObject

Returns the value of attribute documents.



22
23
24
# File 'lib/docusign_click/models/clickwrap_request.rb', line 22

def documents
  @documents
end

#fields_to_nullObject

Returns the value of attribute fields_to_null.



25
26
27
# File 'lib/docusign_click/models/clickwrap_request.rb', line 25

def fields_to_null
  @fields_to_null
end

#is_major_versionObject

Returns the value of attribute is_major_version.



28
29
30
# File 'lib/docusign_click/models/clickwrap_request.rb', line 28

def is_major_version
  @is_major_version
end

#is_sharedObject

Returns the value of attribute is_shared.



31
32
33
# File 'lib/docusign_click/models/clickwrap_request.rb', line 31

def is_shared
  @is_shared
end

#nameObject

Returns the value of attribute name.



34
35
36
# File 'lib/docusign_click/models/clickwrap_request.rb', line 34

def name
  @name
end

#require_reacceptanceObject

Returns the value of attribute require_reacceptance.



37
38
39
# File 'lib/docusign_click/models/clickwrap_request.rb', line 37

def require_reacceptance
  @require_reacceptance
end

#scheduled_dateObject

Returns the value of attribute scheduled_date.



40
41
42
# File 'lib/docusign_click/models/clickwrap_request.rb', line 40

def scheduled_date
  @scheduled_date
end

#scheduled_reacceptanceObject

Returns the value of attribute scheduled_reacceptance.



42
43
44
# File 'lib/docusign_click/models/clickwrap_request.rb', line 42

def scheduled_reacceptance
  @scheduled_reacceptance
end

#statusObject

Returns the value of attribute status.



45
46
47
# File 'lib/docusign_click/models/clickwrap_request.rb', line 45

def status
  @status
end

#transfer_from_user_idObject

Returns the value of attribute transfer_from_user_id.



48
49
50
# File 'lib/docusign_click/models/clickwrap_request.rb', line 48

def transfer_from_user_id
  @transfer_from_user_id
end

#transfer_to_user_idObject

Returns the value of attribute transfer_to_user_id.



51
52
53
# File 'lib/docusign_click/models/clickwrap_request.rb', line 51

def transfer_to_user_id
  @transfer_to_user_id
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/docusign_click/models/clickwrap_request.rb', line 54

def self.attribute_map
  {
    :'clickwrap_name' => :'clickwrapName',
    :'display_settings' => :'displaySettings',
    :'documents' => :'documents',
    :'fields_to_null' => :'fieldsToNull',
    :'is_major_version' => :'isMajorVersion',
    :'is_shared' => :'isShared',
    :'name' => :'name',
    :'require_reacceptance' => :'requireReacceptance',
    :'scheduled_date' => :'scheduledDate',
    :'scheduled_reacceptance' => :'scheduledReacceptance',
    :'status' => :'status',
    :'transfer_from_user_id' => :'transferFromUserId',
    :'transfer_to_user_id' => :'transferToUserId'
  }
end

.swagger_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/docusign_click/models/clickwrap_request.rb', line 73

def self.swagger_types
  {
    :'clickwrap_name' => :'String',
    :'display_settings' => :'DisplaySettings',
    :'documents' => :'Array<Document>',
    :'fields_to_null' => :'String',
    :'is_major_version' => :'BOOLEAN',
    :'is_shared' => :'BOOLEAN',
    :'name' => :'String',
    :'require_reacceptance' => :'BOOLEAN',
    :'scheduled_date' => :'Object',
    :'scheduled_reacceptance' => :'ClickwrapScheduledReacceptance',
    :'status' => :'Object',
    :'transfer_from_user_id' => :'String',
    :'transfer_to_user_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • to be compared



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/docusign_click/models/clickwrap_request.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      clickwrap_name == o.clickwrap_name &&
      display_settings == o.display_settings &&
      documents == o.documents &&
      fields_to_null == o.fields_to_null &&
      is_major_version == o.is_major_version &&
      is_shared == o.is_shared &&
      name == o.name &&
      require_reacceptance == o.require_reacceptance &&
      scheduled_date == o.scheduled_date &&
      scheduled_reacceptance == o.scheduled_reacceptance &&
      status == o.status &&
      transfer_from_user_id == o.transfer_from_user_id &&
      transfer_to_user_id == o.transfer_to_user_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • type Data type

  • value Value to be deserialized

Returns:

  • Deserialized data



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/docusign_click/models/clickwrap_request.rb', line 223

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_Click.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • Any valid value

Returns:

  • Returns the value in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/docusign_click/models/clickwrap_request.rb', line 289

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • Model attributes in the form of hash

Returns:

  • Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/docusign_click/models/clickwrap_request.rb', line 202

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method

Parameters:

  • to be compared

Returns:



189
190
191
# File 'lib/docusign_click/models/clickwrap_request.rb', line 189

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • Hash code



195
196
197
# File 'lib/docusign_click/models/clickwrap_request.rb', line 195

def hash
  [clickwrap_name, display_settings, documents, fields_to_null, is_major_version, is_shared, name, require_reacceptance, scheduled_date, scheduled_reacceptance, status, transfer_from_user_id, transfer_to_user_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
# File 'lib/docusign_click/models/clickwrap_request.rb', line 156

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • Returns the object in the form of hash



269
270
271
# File 'lib/docusign_click/models/clickwrap_request.rb', line 269

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • Returns the object in the form of hash



275
276
277
278
279
280
281
282
283
# File 'lib/docusign_click/models/clickwrap_request.rb', line 275

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • String presentation of the object



263
264
265
# File 'lib/docusign_click/models/clickwrap_request.rb', line 263

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • true if the model is valid



163
164
165
# File 'lib/docusign_click/models/clickwrap_request.rb', line 163

def valid?
  true
end