Class: DocuSign_Click::ClickwrapVersion

Inherits:
Object
  • Object
show all
Defined in:
lib/docusign_click/models/clickwrap_version.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ClickwrapVersion

Initializes the object



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/docusign_click/models/clickwrap_version.rb', line 89

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'clickwrapVersionId')
    self.clickwrap_version_id = attributes[:'clickwrapVersionId']
  end

  if attributes.has_key?(:'createdTime')
    self.created_time = attributes[:'createdTime']
  end

  if attributes.has_key?(:'dataFields')
    if (value = attributes[:'dataFields']).is_a?(Array)
      self.data_fields = value
    end
  end

  if attributes.has_key?(:'lastModified')
    self.last_modified = attributes[:'lastModified']
  end

  if attributes.has_key?(:'lastModifiedBy')
    self.last_modified_by = attributes[:'lastModifiedBy']
  end

  if attributes.has_key?(:'ownerUserId')
    self.owner_user_id = attributes[:'ownerUserId']
  end

  if attributes.has_key?(:'requireReacceptance')
    self.require_reacceptance = attributes[:'requireReacceptance']
  end

  if attributes.has_key?(:'scheduledDate')
    self.scheduled_date = attributes[:'scheduledDate']
  end

  if attributes.has_key?(:'scheduledReacceptance')
    self.scheduled_reacceptance = attributes[:'scheduledReacceptance']
  end

  if attributes.has_key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.has_key?(:'versionId')
    self.version_id = attributes[:'versionId']
  end

  if attributes.has_key?(:'versionNumber')
    self.version_number = attributes[:'versionNumber']
  end
end

Instance Attribute Details

#clickwrap_version_idObject

Returns the value of attribute clickwrap_version_id.



17
18
19
# File 'lib/docusign_click/models/clickwrap_version.rb', line 17

def clickwrap_version_id
  @clickwrap_version_id
end

#created_timeObject

Returns the value of attribute created_time.



20
21
22
# File 'lib/docusign_click/models/clickwrap_version.rb', line 20

def created_time
  @created_time
end

#data_fieldsObject

Returns the value of attribute data_fields.



23
24
25
# File 'lib/docusign_click/models/clickwrap_version.rb', line 23

def data_fields
  @data_fields
end

#last_modifiedObject

Returns the value of attribute last_modified.



26
27
28
# File 'lib/docusign_click/models/clickwrap_version.rb', line 26

def last_modified
  @last_modified
end

#last_modified_byObject

Returns the value of attribute last_modified_by.



29
30
31
# File 'lib/docusign_click/models/clickwrap_version.rb', line 29

def last_modified_by
  @last_modified_by
end

#owner_user_idObject

Returns the value of attribute owner_user_id.



32
33
34
# File 'lib/docusign_click/models/clickwrap_version.rb', line 32

def owner_user_id
  @owner_user_id
end

#require_reacceptanceObject

Returns the value of attribute require_reacceptance.



35
36
37
# File 'lib/docusign_click/models/clickwrap_version.rb', line 35

def require_reacceptance
  @require_reacceptance
end

#scheduled_dateObject

Returns the value of attribute scheduled_date.



38
39
40
# File 'lib/docusign_click/models/clickwrap_version.rb', line 38

def scheduled_date
  @scheduled_date
end

#scheduled_reacceptanceObject

Returns the value of attribute scheduled_reacceptance.



40
41
42
# File 'lib/docusign_click/models/clickwrap_version.rb', line 40

def scheduled_reacceptance
  @scheduled_reacceptance
end

#statusObject

Returns the value of attribute status.



43
44
45
# File 'lib/docusign_click/models/clickwrap_version.rb', line 43

def status
  @status
end

#version_idObject

Returns the value of attribute version_id.



46
47
48
# File 'lib/docusign_click/models/clickwrap_version.rb', line 46

def version_id
  @version_id
end

#version_numberObject

Returns the value of attribute version_number.



49
50
51
# File 'lib/docusign_click/models/clickwrap_version.rb', line 49

def version_number
  @version_number
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/docusign_click/models/clickwrap_version.rb', line 52

def self.attribute_map
  {
    :'clickwrap_version_id' => :'clickwrapVersionId',
    :'created_time' => :'createdTime',
    :'data_fields' => :'dataFields',
    :'last_modified' => :'lastModified',
    :'last_modified_by' => :'lastModifiedBy',
    :'owner_user_id' => :'ownerUserId',
    :'require_reacceptance' => :'requireReacceptance',
    :'scheduled_date' => :'scheduledDate',
    :'scheduled_reacceptance' => :'scheduledReacceptance',
    :'status' => :'status',
    :'version_id' => :'versionId',
    :'version_number' => :'versionNumber'
  }
end

.swagger_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/docusign_click/models/clickwrap_version.rb', line 70

def self.swagger_types
  {
    :'clickwrap_version_id' => :'String',
    :'created_time' => :'Object',
    :'data_fields' => :'Array<DataField>',
    :'last_modified' => :'Object',
    :'last_modified_by' => :'String',
    :'owner_user_id' => :'String',
    :'require_reacceptance' => :'BOOLEAN',
    :'scheduled_date' => :'Object',
    :'scheduled_reacceptance' => :'ClickwrapScheduledReacceptance',
    :'status' => :'String',
    :'version_id' => :'String',
    :'version_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
# File 'lib/docusign_click/models/clickwrap_version.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      clickwrap_version_id == o.clickwrap_version_id &&
      created_time == o.created_time &&
      data_fields == o.data_fields &&
      last_modified == o.last_modified &&
      last_modified_by == o.last_modified_by &&
      owner_user_id == o.owner_user_id &&
      require_reacceptance == o.require_reacceptance &&
      scheduled_date == o.scheduled_date &&
      scheduled_reacceptance == o.scheduled_reacceptance &&
      status == o.status &&
      version_id == o.version_id &&
      version_number == o.version_number
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type



214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/docusign_click/models/clickwrap_version.rb', line 214

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = DocuSign_Click.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/docusign_click/models/clickwrap_version.rb', line 280

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/docusign_click/models/clickwrap_version.rb', line 193

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


180
181
182
# File 'lib/docusign_click/models/clickwrap_version.rb', line 180

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.



186
187
188
# File 'lib/docusign_click/models/clickwrap_version.rb', line 186

def hash
  [clickwrap_version_id, created_time, data_fields, last_modified, last_modified_by, owner_user_id, require_reacceptance, scheduled_date, scheduled_reacceptance, status, version_id, version_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



148
149
150
151
# File 'lib/docusign_click/models/clickwrap_version.rb', line 148

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)



260
261
262
# File 'lib/docusign_click/models/clickwrap_version.rb', line 260

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash



266
267
268
269
270
271
272
273
274
# File 'lib/docusign_click/models/clickwrap_version.rb', line 266

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object



254
255
256
# File 'lib/docusign_click/models/clickwrap_version.rb', line 254

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid



155
156
157
# File 'lib/docusign_click/models/clickwrap_version.rb', line 155

def valid?
  true
end