Class: DocuSign_Click::GetClickwrapVersionAgreementsOptions
- Inherits:
-
Object
- Object
- DocuSign_Click::GetClickwrapVersionAgreementsOptions
- Defined in:
- lib/docusign_click/api/accounts_api.rb
Instance Attribute Summary collapse
-
#client_user_id ⇒ Object
The client user ID to filter to a single user’s agreements.
-
#from_date ⇒ Object
The earliest date to return agreements from.
-
#page_number ⇒ Object
The results for this endpoint are paginated.
-
#status ⇒ Object
User agreement status.
-
#to_date ⇒ Object
The latest date to return agreements from.
Class Method Summary collapse
Instance Attribute Details
#client_user_id ⇒ Object
The client user ID to filter to a single user’s agreements.
75 76 77 |
# File 'lib/docusign_click/api/accounts_api.rb', line 75 def client_user_id @client_user_id end |
#from_date ⇒ Object
The earliest date to return agreements from.
78 79 80 |
# File 'lib/docusign_click/api/accounts_api.rb', line 78 def from_date @from_date end |
#page_number ⇒ Object
The results for this endpoint are paginated. Use this parameter to indicate which page to return. The minimumPagesRemaining value in the response indicates whether to continue querying for additional pages. For example, if the page size is 40: * If this property is set to 0 (the default), the endpoint returns results 1-40. * If this property is set to 1, the endpoint returns results 41-80. The default value is 0.
81 82 83 |
# File 'lib/docusign_click/api/accounts_api.rb', line 81 def page_number @page_number end |
#status ⇒ Object
User agreement status. One of: - created - agreed - declined
84 85 86 |
# File 'lib/docusign_click/api/accounts_api.rb', line 84 def status @status end |
#to_date ⇒ Object
The latest date to return agreements from.
87 88 89 |
# File 'lib/docusign_click/api/accounts_api.rb', line 87 def to_date @to_date end |
Class Method Details
.default ⇒ Object
89 90 91 |
# File 'lib/docusign_click/api/accounts_api.rb', line 89 def self.default @@default ||= GetClickwrapVersionAgreementsOptions.new end |