Class: DocuSign_Click::GetClickwrapsOptions
- Inherits:
-
Object
- Object
- DocuSign_Click::GetClickwrapsOptions
- Defined in:
- lib/docusign_click/api/accounts_api.rb
Instance Attribute Summary collapse
-
#filter ⇒ Object
Names of columns by which to filter and values to match on.
-
#from_date ⇒ Object
The earliest date to return clickwraps from.
-
#name ⇒ Object
The name of the clickwraps to return.
-
#owner_user_id ⇒ Object
The user ID of the owner.
-
#page_number ⇒ Object
The results for this endpoint are paginated.
-
#status ⇒ Object
The status of the clickwraps to filter by.
-
#to_date ⇒ Object
The latest date to return clickwraps from.
Class Method Summary collapse
Instance Attribute Details
#filter ⇒ Object
Names of columns by which to filter and values to match on.
96 97 98 |
# File 'lib/docusign_click/api/accounts_api.rb', line 96 def filter @filter end |
#from_date ⇒ Object
The earliest date to return clickwraps from.
99 100 101 |
# File 'lib/docusign_click/api/accounts_api.rb', line 99 def from_date @from_date end |
#name ⇒ Object
The name of the clickwraps to return.
102 103 104 |
# File 'lib/docusign_click/api/accounts_api.rb', line 102 def name @name end |
#owner_user_id ⇒ Object
The user ID of the owner.
105 106 107 |
# File 'lib/docusign_click/api/accounts_api.rb', line 105 def owner_user_id @owner_user_id end |
#page_number ⇒ Object
The results for this endpoint are paginated. Use this parameter to indicate which page to return. The minimumPagesRemaining value in the response indicates whether to continue querying for additional pages. For example, if the page size is 40: * If this property is set to 0 (the default), the endpoint returns results 1-40. * If this property is set to 1, the endpoint returns results 41-80. The default value is 0.
108 109 110 |
# File 'lib/docusign_click/api/accounts_api.rb', line 108 def page_number @page_number end |
#status ⇒ Object
The status of the clickwraps to filter by. One of: - active - inactive
111 112 113 |
# File 'lib/docusign_click/api/accounts_api.rb', line 111 def status @status end |
#to_date ⇒ Object
The latest date to return clickwraps from.
114 115 116 |
# File 'lib/docusign_click/api/accounts_api.rb', line 114 def to_date @to_date end |
Class Method Details
.default ⇒ Object
116 117 118 |
# File 'lib/docusign_click/api/accounts_api.rb', line 116 def self.default @@default ||= GetClickwrapsOptions.new end |